@@ -22,6 +22,9 @@
 
 #include <gpds-ui.h>
 #include <gpds-module-impl.h>
+#include <gpds-gconf.h>
+#include <gpds-utils.h>
+#include <gpds-gconf.h>
 
 #endif /* __GPOINTING_DEVICE_SETTINGS_H__ */
 /*
