@@ -7,9 +7,11 @@ void test_exist_device (void);
 void test_get_float_atom (void);
 void test_get_device_info (void);
 void test_open_device (void);
+void test_open_no_device (void);
 void test_get_device_num_buttons (void);
 
 static GError *error;
+static GError *expected_error;
 static XDevice *device;
 
 #define DEVICE_NAME "Macintosh mouse button emulation"
@@ -19,6 +21,7 @@ setup (void)
 {
     error = NULL;
     device = NULL;
+    expected_error = NULL;
 }
 
 void
@@ -27,6 +30,7 @@ teardown (void)
     if (device)
         XCloseDevice(GDK_DISPLAY(), device);
     g_clear_error(&error);
+    g_clear_error(&expected_error);
 }
 
 void
@@ -46,8 +50,10 @@ void
 test_get_device_info (void)
 {
     XDeviceInfo *device_info = NULL; 
-    device_info = gpds_xinput_utils_get_device_info(DEVICE_NAME);
+    device_info = gpds_xinput_utils_get_device_info(DEVICE_NAME, &error);
     cut_assert(device_info);
+
+    gcut_assert_error(error);
 }
 
 void
@@ -59,6 +65,17 @@ test_open_device (void)
     gcut_assert_error(error);
 }
 
+void
+test_open_no_device (void)
+{
+    expected_error = g_error_new(GPDS_XINPUT_UTILS_ERROR,
+                                 GPDS_XINPUT_UTILS_ERROR_NO_DEVICE,
+                                 "No Invalid device found.");
+    device = gpds_xinput_utils_open_device("Invalid device", &error);
+
+    gcut_assert_equal_error(expected_error, error);
+}
+
 void
 test_get_device_num_buttons (void)
 {
